[−][src]Enum unicode_types::bhaiksuki::Bhaiksuki
An enum to represent all characters in the Bhaiksuki block.
Variants
LetterA\u{11c00}: '𑰀'
LetterAa\u{11c01}: '𑰁'
LetterI\u{11c02}: '𑰂'
LetterIi\u{11c03}: '𑰃'
LetterU\u{11c04}: '𑰄'
LetterUu\u{11c05}: '𑰅'
LetterVocalicR\u{11c06}: '𑰆'
LetterVocalicRr\u{11c07}: '𑰇'
LetterVocalicL\u{11c08}: '𑰈'
LetterE\u{11c0a}: '𑰊'
LetterAi\u{11c0b}: '𑰋'
LetterO\u{11c0c}: '𑰌'
LetterAu\u{11c0d}: '𑰍'
LetterKa\u{11c0e}: '𑰎'
LetterKha\u{11c0f}: '𑰏'
LetterGa\u{11c10}: '𑰐'
LetterGha\u{11c11}: '𑰑'
LetterNga\u{11c12}: '𑰒'
LetterCa\u{11c13}: '𑰓'
LetterCha\u{11c14}: '𑰔'
LetterJa\u{11c15}: '𑰕'
LetterJha\u{11c16}: '𑰖'
LetterNya\u{11c17}: '𑰗'
LetterTta\u{11c18}: '𑰘'
LetterTtha\u{11c19}: '𑰙'
LetterDda\u{11c1a}: '𑰚'
LetterDdha\u{11c1b}: '𑰛'
LetterNna\u{11c1c}: '𑰜'
LetterTa\u{11c1d}: '𑰝'
LetterTha\u{11c1e}: '𑰞'
LetterDa\u{11c1f}: '𑰟'
LetterDha\u{11c20}: '𑰠'
LetterNa\u{11c21}: '𑰡'
LetterPa\u{11c22}: '𑰢'
LetterPha\u{11c23}: '𑰣'
LetterBa\u{11c24}: '𑰤'
LetterBha\u{11c25}: '𑰥'
LetterMa\u{11c26}: '𑰦'
LetterYa\u{11c27}: '𑰧'
LetterRa\u{11c28}: '𑰨'
LetterLa\u{11c29}: '𑰩'
LetterVa\u{11c2a}: '𑰪'
LetterSha\u{11c2b}: '𑰫'
LetterSsa\u{11c2c}: '𑰬'
LetterSa\u{11c2d}: '𑰭'
LetterHa\u{11c2e}: '𑰮'
VowelSignAa\u{11c2f}: '𑰯'
VowelSignI\u{11c30}: '𑰰'
VowelSignIi\u{11c31}: '𑰱'
VowelSignU\u{11c32}: '𑰲'
VowelSignUu\u{11c33}: '𑰳'
VowelSignVocalicR\u{11c34}: '𑰴'
VowelSignVocalicRr\u{11c35}: '𑰵'
VowelSignVocalicL\u{11c36}: '𑰶'
VowelSignE\u{11c38}: '𑰸'
VowelSignAi\u{11c39}: '𑰹'
VowelSignO\u{11c3a}: '𑰺'
VowelSignAu\u{11c3b}: '𑰻'
SignCandrabindu\u{11c3c}: '𑰼'
SignAnusvara\u{11c3d}: '𑰽'
SignVisarga\u{11c3e}: '𑰾'
SignVirama\u{11c3f}: '𑰿'
SignAvagraha\u{11c40}: '𑱀'
Danda\u{11c41}: '𑱁'
DoubleDanda\u{11c42}: '𑱂'
WordSeparator\u{11c43}: '𑱃'
GapFillerDash1\u{11c44}: '𑱄'
GapFillerDash2\u{11c45}: '𑱅'
DigitZero\u{11c50}: '𑱐'
DigitOne\u{11c51}: '𑱑'
DigitTwo\u{11c52}: '𑱒'
DigitThree\u{11c53}: '𑱓'
DigitFour\u{11c54}: '𑱔'
DigitFive\u{11c55}: '𑱕'
DigitSix\u{11c56}: '𑱖'
DigitSeven\u{11c57}: '𑱗'
DigitEight\u{11c58}: '𑱘'
DigitNine\u{11c59}: '𑱙'
NumberOne\u{11c5a}: '𑱚'
NumberTwo\u{11c5b}: '𑱛'
NumberThree\u{11c5c}: '𑱜'
NumberFour\u{11c5d}: '𑱝'
NumberFive\u{11c5e}: '𑱞'
NumberSix\u{11c5f}: '𑱟'
NumberSeven\u{11c60}: '𑱠'
NumberEight\u{11c61}: '𑱡'
NumberNine\u{11c62}: '𑱢'
NumberTen\u{11c63}: '𑱣'
NumberTwenty\u{11c64}: '𑱤'
NumberThirty\u{11c65}: '𑱥'
NumberForty\u{11c66}: '𑱦'
NumberFifty\u{11c67}: '𑱧'
NumberSixty\u{11c68}: '𑱨'
NumberSeventy\u{11c69}: '𑱩'
NumberEighty\u{11c6a}: '𑱪'
NumberNinety\u{11c6b}: '𑱫'
HundredsUnitMark\u{11c6c}: '𑱬'
Methods
impl Bhaiksuki[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case